aboutsummaryrefslogtreecommitdiffstats
path: root/src/gpg/result_analyse/ResultAnalyse.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/gpg/result_analyse/ResultAnalyse.cpp')
-rw-r--r--src/gpg/result_analyse/ResultAnalyse.cpp22
1 files changed, 13 insertions, 9 deletions
diff --git a/src/gpg/result_analyse/ResultAnalyse.cpp b/src/gpg/result_analyse/ResultAnalyse.cpp
index 7186d21a..821da2ee 100644
--- a/src/gpg/result_analyse/ResultAnalyse.cpp
+++ b/src/gpg/result_analyse/ResultAnalyse.cpp
@@ -1,7 +1,7 @@
/**
* This file is part of GPGFrontend.
*
* GPGFrontend is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
@@ -24,15 +24,19 @@
#include "gpg/result_analyse/ResultAnalyse.h"
-const QString &ResultAnalyse::getResultReport() const{
- return resultText;
+const std::string GpgFrontend::ResultAnalyse::getResultReport() const {
+ return stream.str();
}
-int ResultAnalyse::getStatus() const {
- return status;
+int GpgFrontend::ResultAnalyse::getStatus() const { return status; }
+
+void GpgFrontend::ResultAnalyse::setStatus(int mStatus) {
+ if (mStatus < status) status = mStatus;
}
-void ResultAnalyse::setStatus(int mStatus) {
- if(mStatus < status)
- status = mStatus;
+void GpgFrontend::ResultAnalyse::analyse() {
+ if (!analysed_) {
+ do_analyse();
+ analysed_ = true;
+ }
}
@@ -1,7 +1,7 @@
/**
- * This file is part of GPGFrontend.
+ * This file is part of GpgFrontend.
*
@@ -1,7 +1,7 @@
*
- * GPGFrontend is free software: you can redistribute it and/or modify
+ * GpgFrontend is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or